]> jfr.im git - yt-dlp.git/blobdiff - setup.py
Merge branch 'twitch-fix' of https://github.com/lel-amri/youtube-dl into lel-amri...
[yt-dlp.git] / setup.py
index 23553b88a923ad8203ce5f45ee778ae4d9319ab2..f5f0bae62401cecaa63d26ff7c72982b9812f182 100644 (file)
--- a/setup.py
+++ b/setup.py
@@ -1,15 +1,15 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-from setuptools import setup, Command
+from setuptools import setup, Command, find_packages
 import os.path
 import warnings
 import sys
 from distutils.spawn import spawn
 
-# Get the version from youtube_dl/version.py without importing the package
-exec(compile(open('youtube_dl/version.py').read(),
-             'youtube_dl/version.py', 'exec'))
+# Get the version from youtube_dlc/version.py without importing the package
+exec(compile(open('youtube_dlc/version.py').read(),
+             'youtube_dlc/version.py', 'exec'))
 
 DESCRIPTION = 'Media downloader supporting various sites such as youtube'
 LONG_DESCRIPTION = 'Command-line program to download videos from YouTube.com and other video sites. Based on a more active community fork.'
     print("inv")
 else:
     files_spec = [
-        ('etc/bash_completion.d', ['youtube-dl.bash-completion']),
-        ('etc/fish/completions', ['youtube-dl.fish']),
-        ('share/doc/youtube_dl', ['README.txt']),
-        ('share/man/man1', ['youtube-dl.1'])
+        ('etc/bash_completion.d', ['youtube-dlc.bash-completion']),
+        ('etc/fish/completions', ['youtube-dlc.fish']),
+        ('share/doc/youtube_dlc', ['README.txt']),
+        ('share/man/man1', ['youtube-dlc.1'])
     ]
     root = os.path.dirname(os.path.abspath(__file__))
     data_files = []
@@ -38,7 +38,7 @@
         'data_files': data_files,
     }
     #if setuptools_available:
-    params['entry_points'] = {'console_scripts': ['youtube-dlc = youtube_dl:main']}
+    params['entry_points'] = {'console_scripts': ['youtube-dlc = youtube_dlc:main']}
     #else:
     #    params['scripts'] = ['bin/youtube-dlc']
 
@@ -54,7 +54,7 @@ def finalize_options(self):
 
     def run(self):
         spawn(
-            [sys.executable, 'devscripts/make_lazy_extractors.py', 'youtube_dl/extractor/lazy_extractors.py'],
+            [sys.executable, 'devscripts/make_lazy_extractors.py', 'youtube_dlc/extractor/lazy_extractors.py'],
             dry_run=self.dry_run,
         )
 
@@ -67,11 +67,11 @@ def run(self):
     long_description=LONG_DESCRIPTION,
     # long_description_content_type="text/markdown",
     url="https://github.com/blackjack4494/youtube-dlc",
-    # packages=setuptools.find_packages(),
-       packages=[
-        'youtube_dl',
-        'youtube_dl.extractor', 'youtube_dl.downloader',
-        'youtube_dl.postprocessor'],
+    packages=find_packages(exclude=("youtube_dl",)),
+       #packages=[
+    #    'youtube_dlc',
+    #    'youtube_dlc.extractor', 'youtube_dlc.downloader',
+    #    'youtube_dlc.postprocessor'],
     classifiers=[
            "Topic :: Multimedia :: Video",
         "Development Status :: 5 - Production/Stable",